#
# spec file for package scsirastools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scsirastools
Version:        1.6.6
Release:        bp160.1.7
Summary:        Serviceability for SCSI Disks and Arrays
License:        BSD-3-Clause
Group:          Hardware/Other
URL:            http://scsirastools.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}-%{version}.tar.gz
Source1:        sgdisk.service
Source2:        sgraid.service
Patch0:         %{name}-1.6.4-SUSE.diff
Patch2:         %{name}-install
Patch3:         %{name}-single-dev.diff
Patch4:         %{name}-stop-using-var-lock-subsys.patch
Patch5:         %{name}-add-systemd-support.patch
BuildRequires:  automake
BuildRequires:  systemd-rpm-macros
Requires:       mdadm
%{?systemd_ordering}

%description
The SCSI RAS (Reliability, Availability, and Serviceability) tools
work with SCSI devices used in a Linux software RAID-1 configuration.

* sgraidmon - a tool to monitor software RAID disks for
  hot-insertion/removal
* sgdefects - a tool to read the primary and grown defect lists
* sgdskfl - a tool to load disk firmware to SCSI disks under Linux
* sgmode - a tool to get and set SCSI device mode pages
* sgdiag - a tool to perform format and other diagnostic functions

The tools require SCSIRAS patches in the kernel; these are not
present in SUSE-provided kernels.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
# usrmerge
mv %{buildroot}/sbin/* %{buildroot}%{_sbindir}/
# systemd support
# 1) move the sysv init scripts away
install -d %{buildroot}%{_datadir}/scsirastools/scripts
mv %{buildroot}%{_initddir}/sgraid %{buildroot}%{_datadir}/scsirastools/scripts
mv %{buildroot}%{_initddir}/sgdisk %{buildroot}%{_datadir}/scsirastools/scripts
install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE1} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}

%files
%{_sbindir}/sg*
%{_sbindir}/md*
%{_sbindir}/getmd
%{_datadir}/scsirastools
%config %{_datadir}/scsirastools/scripts/sgraid
%config %{_datadir}/scsirastools/scripts/sgdisk
%{_unitdir}/sgdisk.service
%{_unitdir}/sgraid.service
%{_mandir}/man8/sg*.8.gz
%dir %{_datadir}/scsirastools
%{_datadir}/scsirastools/*.mdf
%{_datadir}/scsirastools/rescan-scsi-bus.sh
%doc %{_defaultdocdir}/%{name}

%pre
%service_add_pre sgdisk.service sgraid.service

%post
%service_add_post sgdisk.service sgraid.service

%preun
%service_del_preun sgdisk.service sgraid.service

%postun
%service_del_postun sgdisk.service sgraid.service

%changelog
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.6:
  src/sgcommon.c,sgsubmon.c - include <sys/sysmacros.h>
- scsirastools-add-systemd-support.patch: refresh
* Thu Dec  1 2022 Jan Engelhardt <jengelh@inai.de>
- Compact description and fix the broken markup for the tool list.
- Remove old specfile constructs.
* Thu Oct 20 2022 Ludwig Nussel <lnussel@suse.de>
- Use /usr/sbin (boo#1191093)
* Fri Mar 29 2019 Jan Engelhardt <jengelh@inai.de>
- Combine %%service_* to reduce generated boilerplate.
- %%service_* needs systemd-rpm-macros.
- Install service files with standard permissions.
- Modernize specfile macros a bit.
* Thu Mar 14 2019 josef.moellers@suse.com
- Added systemd support.
  [bsc#1116036, scsirastools-add-systemd-support.patch,
  sgdisk.service, sgraid.service]
* Mon Mar 20 2017 meissner@suse.com
- prerequire insserv_prereq
* Mon Mar 16 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use %%configure macro
* Fri Oct 26 2012 lduncan@suse.com
- Added scsirastools-stop-using-var-lock-subsys.patch: remove use
  of /var/lock/subsys in service init files (bnc#714645)
* Wed Oct 24 2012 meissner@suse.com
- added URL to Source0.
* Sat Oct 20 2012 david.bahi@emc.com
- updated the scsirastools-1.4.9-SUSE.diff patch to scsirastools-1.6.4-SUSE.diff
  + corrected the sysvinit scripts for proper status behavior/output
* Wed Jan 18 2012 tabraham@novell.com
- removed patches deprecated by this release:
  + scsirastools-1.5.8-glibc210.diff
- removed alarms/ialarms refer to ipmiutil
- Updated to 1.6.4
  + updated SCSI asc,ascq table from www.t10.org
- Updates from 1.6.3
  + various bug fixes
- Updates from 1.6.2
  + add capability to turn off SMART, fixup for -o if no block desc
  + do not mark as failed if sernum is zero length
  + added -s, -w, -o, -I descriptions to man page
  + updated sgmode section of UserGuide
- Updates from 1.6.1
  + various bug fixes
- Updates from 1.6.0
  + default for each utility is no longer interactive
  + added Fujitsu MAP3147NC, Seagate ST318406LC, Seagate ST336605LW,
    Seagate ST336607LW, and Seagate ST373405LW
* Mon Jan  9 2012 aj@suse.de
- Do not use runlevel 4
- Comment on download URL
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Jun 16 2009 coolo@novell.com
- fix build with glibc 2.10
* Fri Aug 22 2008 garloff@suse.de
- Adapt init scripts (more needed)
- Update to 1.5.8:
  * Various bug fixes
  * Support for larger device lists
  * Fujitsu disk fw bug workarounds
  * SES enclosure slot status support
  * Docu updates
  * New: sgdiskmon
* Thu Jul 20 2006 schwab@suse.de
- Use autoreconf.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 23 2005 garloff@suse.de
- Correct add-single-device syntax. [#46815]
- Update to scsirastools-1.4.10:
  * sgraidmon: start_unit for sense 2:4:1 before reset
* Fri Sep 10 2004 schwab@suse.de
- Remove useless binary from shared data dir.
* Fri Aug 20 2004 garloff@suse.de
- Don't remove files from source dir when installing.
* Mon Aug 16 2004 garloff@suse.de
- Update to scsirastools-1.4.9:
  * sgdiag: Document -t option, default format timeout 150min now.
- Update to scsirastools-1.4.8:
  * sgraidmon: mdevt and mdevents log docu
- Update to scsirastools-1.4.6:
  * mdevt: fix mBMC disk fault LED logic
- Update to scsirastools-1.4.5:
  alarms: mew tool, sets disk fault LEDs
* Thu Mar 18 2004 garloff@suse.de
- Fix permissions (#36336).
* Mon Feb 16 2004 garloff@suse.de
- Update to scsirastools-1.4.4:
  * Various improvements to sgraidmon.
* Tue Oct 14 2003 garloff@suse.de
- Update to scsirastools-1.4.3:
  * 64 bit cleanliness
  * Docu updates
- Update to scsirastools-1.4.2:
  * sgmode: adjust format dev page if block size changes
  * sgraidmon: return value, debug log, check for last dev in raid
    (#30603)
  * sgafte: new util
  * mdevt: grub boot images are in menu.lst
- Update to scsirastools-1.4.1: Support for 12byte serial numbers.
- Update to scsirastools-1.4.0: SUSE patches have been incor-
  porated :-)
* Sat Apr 12 2003 garloff@suse.de
- Fix devfs detection in sgraidmon as well.
* Thu Apr 10 2003 garloff@suse.de
- Fix devfs detection.
* Wed Apr  2 2003 garloff@suse.de
- Include errno.h in getmd
* Wed Apr  2 2003 garloff@suse.de
- Update to 1.3.9 which comes without the firmwares (whose license
  is unclear).
* Wed Apr  2 2003 garloff@suse.de
- Fix init script.
* Wed Apr  2 2003 garloff@suse.de
- Split package into scsirastools and scsirastools-firmware
* Wed Apr  2 2003 garloff@suse.de
- Initial creation of scsirastools-1.3.8
- Disabled build of mdadm (it's provided by an own package)
- Fixed paths to be LSB compliant
- Fixed init script to be UL compliant
